@@ -1,22 +1,25 @@
 <?php
-/* $Id: db_datadict.php,v 2.24 2006/07/09 23:24:08 lem9 Exp $ */
-
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ *
+ * @version $Id: db_datadict.php 11334 2008-06-21 13:16:05Z lem9 $
+ */
 
 /**
  * Gets the variables sent or posted to this script, then displays headers
  */
-require_once('./libraries/common.lib.php');
+require_once './libraries/common.inc.php';
 
 if (!isset($selected_tbl)) {
-    require_once('./libraries/header.inc.php');
+    require_once './libraries/header.inc.php';
 }
 
 
 /**
  * Gets the relations settings
  */
-require_once('./libraries/relation.lib.php');
-require_once('./libraries/transformations.lib.php');
+require_once './libraries/relation.lib.php';
+require_once './libraries/transformations.lib.php';
 
 $cfgRelation  = PMA_getRelationsParam();
 
@@ -28,10 +31,10 @@ PMA_checkParameters(array('db'));
 /**
  * Defines the url to return to in case of error in a sql statement
  */
-if (isset($table)) {
-    $err_url = 'tbl_properties.php?' . PMA_generate_common_url($db, $table);
+if (strlen($table)) {
+    $err_url = 'tbl_sql.php?' . PMA_generate_common_url($db, $table);
 } else {
-    $err_url = 'db_details.php?' . PMA_generate_common_url($db);
+    $err_url = 'db_sql.php?' . PMA_generate_common_url($db);
 }
 
 if ($cfgRelation['commwork']) {
@@ -42,8 +45,8 @@ if ($cfgRelation['commwork']) {
      */
     if (is_array($comment)) {
         ?>
-    <p> <?php echo $strDBComment; ?> 
-        <i><?php echo htmlspecialchars( implode( ' ', $comment ) ); ?></i></p>
+    <p> <?php echo $strDBComment; ?>
+        <i><?php echo htmlspecialchars(implode(' ', $comment)); ?></i></p>
         <?php
     } // end if
 }
@@ -74,10 +77,10 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
      * Gets table informations
      */
     // The 'show table' statement works correct since 3.23.03
-    $showtable    = PMA_DBI_get_tables_full( $db, $table );
+    $showtable    = PMA_DBI_get_tables_full($db, $table);
     $num_rows     = (isset($showtable[$table]['TABLE_ROWS']) ? $showtable[$table]['TABLE_ROWS'] : 0);
     $show_comment = (isset($showtable[$table]['TABLE_COMMENT']) ? $showtable[$table]['TABLE_COMMENT'] : '');
-    unset( $showtable );
+    unset($showtable);
 
 
     /**
@@ -100,7 +103,7 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
             $pk_array[$row['Column_name']] = 1;
         }
         // Retains keys informations
-        if ($row['Key_name'] != $lastIndex ){
+        if ($row['Key_name'] != $lastIndex){
             $indexes[] = $row['Key_name'];
             $lastIndex = $row['Key_name'];
         }
@@ -162,13 +165,13 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
      * Displays the comments of the table if MySQL >= 3.23
      */
     if (!empty($show_comment)) {
-        echo $strTableComments . ': ' . $show_comment . '<br /><br />';
+        echo $strTableComments . ': ' . htmlspecialchars($show_comment) . '<br /><br />';
     }
 
     /**
      * Displays the table structure
      */
-    ?> 
+    ?>
 
 <table width="100%" class="print">
 <tr><th width="50"><?php echo $strField; ?></th>
@@ -238,14 +241,16 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
         // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
         // NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
         // the latter.
-	// TODO: merge this logic with the one in tbl_properties_structure.php
-	// or move it in a function similar to PMA_DBI_get_columns_full()
-	// but based on SHOW CREATE TABLE because information_schema
-	// cannot be trusted in this case (MySQL bug)
+        /**
+         * @todo merge this logic with the one in tbl_structure.php
+         * or move it in a function similar to PMA_DBI_get_columns_full()
+         * but based on SHOW CREATE TABLE because information_schema
+         * cannot be trusted in this case (MySQL bug)
+         */
         if (!empty($analyzed_sql[0]['create_table_fields'][$field_name]['type']) && $analyzed_sql[0]['create_table_fields'][$field_name]['type'] == 'TIMESTAMP' && $analyzed_sql[0]['create_table_fields'][$field_name]['timestamp_not_null']) {
             $row['Null'] = '';
         }
-        ?> 
+        ?>
 <tr class="<?php echo $odd_row ? 'odd' : 'even'; $odd_row = ! $odd_row; ?>">
     <td nowrap="nowrap">
         <?php
@@ -254,7 +259,7 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
         } else {
             echo $field_name;
         }
-        ?> 
+        ?>
     </td>
     <td<?php echo $type_nowrap; ?> xml:lang="en" dir="ltr"><?php echo $type; ?></td>
 <?php /*    <td<?php echo $type_nowrap; ?>><?php echo $strAttribute; ?></td>*/ ?>
@@ -289,9 +294,9 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
 </tr>
         <?php
     } // end while
-    PMA_DBI_free_result( $result );
+    PMA_DBI_free_result($result);
     $count++;
-    ?> 
+    ?>
 </table>
 </div>
     <?php
@@ -300,8 +305,8 @@ while ($row = PMA_DBI_fetch_assoc($rowset)) {
 /**
  * Displays the footer
  */
-?> 
-<script type="text/javascript" language="javascript">
+?>
+<script type="text/javascript">
 //<![CDATA[
 function printPage()
 {
@@ -317,5 +322,5 @@ function printPage()
 <?php
 echo '<br /><br /><input type="button" id="print" value="' . $strPrint . '" onclick="printPage()" />';
 
-require_once('./libraries/footer.inc.php');
+require_once './libraries/footer.inc.php';
 ?>
