@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_simplified-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: chinese_simplified-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 /**
  * Last translation by: Funda Wang <fundawang@en2china.com>
@@ -66,7 +66,6 @@ $strAscending = '递增';
 $strAtBeginningOfTable = '于表开头';
 $strAtEndOfTable = '于表结尾';
 $strAttr = '属性';
-$strAutodetect = '自动检测';
 $strAutomaticLayout = '自动套用格式';
 
 $strBack = '返回';
@@ -155,7 +154,6 @@ $strCreatePdfFeat = '创建 PDF';
 $strCreationDates = '创建/更新/日期检查';
 $strCriteria = '条件';
 $strCroatian = '克罗地亚语';
-$strCSVOptions = 'CSV 选项';
 $strCyrillic = '西里尔语';
 $strCzech = '捷克语';
 $strCzechSlovak = '捷克斯洛伐克语';
@@ -166,7 +164,6 @@ $strDatabase = '数据库';
 $strDatabaseEmpty = '这个数据库名字是空！';
 $strDatabaseExportOptions = '数据库导出选项';
 $strDatabaseHasBeenDropped = '数据库 %s 已被删除。';
-$strDatabaseNoTable = '此数据库中没有表！';
 $strDatabases = '数据库';
 $strDatabasesDropped = '已经成功删除了 %s 个数据库。';
 $strDatabasesStats = '数据库统计';
@@ -227,7 +224,6 @@ $strError = '错误';
 $strEscapeWildcards = '通配符 _ 及 % 应正确地加入 \ ';
 $strEstonian = '爱沙尼亚语';
 $strExcelEdition = 'Excel 版本';
-$strExcelOptions = 'Excel 选项';
 $strExecuteBookmarked = '执行书签中的查询';
 $strExplain = '解释 SQL';
 $strExport = '导出';
@@ -238,7 +234,6 @@ $strFailedAttempts = '尝试失败';
 $strField = '字段';
 $strFieldHasBeenDropped = '字段 %s 已被删除';
 $strFields = '字段数';
-$strFieldsEmpty = ' 字段总数是空的！';
 $strFieldsEnclosedBy = '包裹字段的字符';
 $strFieldsEscapedBy = '转义字段的字符';
 $strFieldsTerminatedBy = '分隔字段的字符';
@@ -271,7 +266,6 @@ $strHasBeenAltered = '已经被修改。';
 $strHasBeenCreated = '已经建立。';
 $strHaveToShow = '您需要最少选择显示一列';
 $strHebrew = '希伯来语';
-$strHexForBinary = '二进制区域使用十六进制显示';
 $strHome = '主目录';
 $strHomepageOfficial = 'phpMyAdmin 官方网站';
 $strHost = '主机';
@@ -289,10 +283,7 @@ $strIndexes = '索引';
 $strIndexHasBeenDropped = '索引 %s 已被删除';
 $strIndexName = '索引名称：';
 $strIndexType = '索引类型：';
-$strIndexWarningMultiple = '警告：超过一个 %s  键被设在字段 `%s`中';
-$strIndexWarningPrimary = '警告：主键PRIMARY与索引键INDEX不应同时设在字段 `%s` 中';
 $strIndexWarningTable = '警告：数据表 `%s`的索引存在问题';
-$strIndexWarningUnique = '警告：唯一键UNIQUE与索引键INDEX不应同时设在字段 `%s` 中';
 $strInnodbStat = 'InnoDB 状态';
 $strInsecureMySQL = '您配置文件中的设定与 MySQL 默认权限账户对应(没有密码的 root)。您的 MySQL 服务器使用默认值运行当然没有问题，不过这样的话，被入侵的可能性会很大，您真的应该先补上这个安全漏洞。';
 $strInsert = '插入';
@@ -321,7 +312,6 @@ $strLatexContinuedCaption = '延续的表的标题';
 $strLatexIncludeCaption = '包含表的标题';
 $strLatexLabel = '关键标签';
 $strLaTeX = 'LaTeX';  // use eng
-$strLaTeXOptions = 'LaTeX 选项';
 $strLatexStructure = '__TABLE__ 表的结构';
 $strLatvian = '拉脱维亚语';
 $strLengthSet = '长度/值*';
@@ -581,7 +571,6 @@ $strSpaceUsage = '已使用空间';
 $strSpanish = '西班牙语';
 $strSplitWordsWithSpace = '每个单词以空格 (" ") 分隔。';
 $strSQLExportType = '导出类型';
-$strSQLOptions = 'SQL 选项';
 $strSQLParserBugMessage = '有可能您发现了 SQL 分析器的臭虫。请仔细检查您的查询，包括引号是否正确及是否匹配。其它可能的失败原因可能由于您上传了超过引用文本区域外的二进制数据。您还可以在 MySQL 命令行界面试一下您的查询。如果可能的话，以下会列出 MySQL 服务器的错误输出，这可能对您解决问题有一定的帮助作用。如果您仍然有问题，或者命令行界面执行成功而分析器出错，请将您的 SQL 查询缩减到导致问题的某一条语句，然后和下面剪切区中的数据一起提交一个臭虫报告：';
 $strSQLParserUserError = '您的 SQL 查询可能有错。如果可能的话，以下会列出 MySQL 服务器的错误输出，这可能对您解决问题有一定的帮助作用。';
 $strSQLQuery = 'SQL 查询';
@@ -721,7 +710,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -749,9 +737,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -782,11 +768,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -814,7 +798,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -910,7 +893,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -949,7 +932,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -984,16 +966,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1009,7 +987,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1054,4 +1031,27 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
