@@ -1,14 +1,14 @@
 <?php
-/* $Id: finnish-iso-8859-15.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: finnish-iso-8859-1.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 /*
  * Translated by Jouni Khknen, <address withdrawn>
  * Previous translations by Visa Kopu, <visa@visakopu.net>
  */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('tavua', 'kt', 'Mt', 'Gt', 'Tt', 'Pt', 'Et');
@@ -71,7 +71,6 @@ $strAscending = 'Nouseva';
 $strAtBeginningOfTable = 'Taulun alkuun';
 $strAtEndOfTable = 'Taulun loppuun';
 $strAttr = 'Attribuutit';
-$strAutodetect = 'Mrit automaattisesti';
 $strAutomaticLayout = 'Automaattinen ulkoasu';
 
 $strBack = 'Takaisin';
@@ -185,8 +184,6 @@ $strCreationDates = 'Luonti/pivitys/tarkistus -pivykset';
 $strCriteria = 'Hakuehdot';
 $strCroatian = 'Kroaatti';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV-valinnat';
-$strCSVOptions = 'CSV-valinnat';
 $strCyrillic = 'Kyrillinen';
 $strCzechSlovak = 'Tsekkoslovakialainen';
 $strCzech = 'Tshekkilinen';
@@ -195,7 +192,6 @@ $strDanish = 'Tanskalainen';
 $strDatabaseEmpty = 'Tietokannan nimi on tyhj!';
 $strDatabaseExportOptions = 'Tietokannan tulostusvalinnat';
 $strDatabaseHasBeenDropped = 'Tietokanta %s on pudotettu.';
-$strDatabaseNoTable = 'Tm tietokanta ei sisll yhtn taulua!';
 $strDatabasesDropped = '%s tietokantaa pudotettiin onnistuneesti.';
 $strDatabasesStatsDisable = 'Poista tilastot kytst';
 $strDatabasesStatsEnable = 'Ota tilastot kyttn';
@@ -242,7 +238,6 @@ $strDisplayOrder = 'Lajittelujrjestys:';
 $strDisplayPDF = 'Nyt PDF-kaavio';
 $strDoAQuery = 'Suorita "esimerkin mukainen kysely" (jokerimerkki: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL:n valinnat';
 $strDocu = 'Ohjeet';
 $strDoYouReally = 'Oletko varma ett haluat ';
 $strDropDatabaseStrongWarning = 'Olet aikeissasi HVITT kokonaisen tietokannan!';
@@ -280,7 +275,6 @@ $strEscapeWildcards = 'Jokerimerkkien _ ja % eteen on listtv \-merkki, jotta ne
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Virolainen';
 $strExcelEdition = 'Excel-muokkaus';
-$strExcelOptions = 'Excel-valinnat';
 $strExecuteBookmarked = 'Suorita kirjanmerkkeihin listty kysynt';
 $strExplain = 'Selit SQL-kysely';
 $strExportImportToScale = 'Vie/tuo skaalaan';
@@ -291,8 +285,8 @@ $strExtra = 'Listiedot';
 
 $strFailedAttempts = 'Eponnistuneet yritykset';
 $strFieldHasBeenDropped = 'Sarake %s on pudotettu';
+$strFieldInsertFromFileTempDirNotExists = 'Virhe lhetetty tiedostoa siirrettess, katso FAQ 1.11';
 $strField = 'Sarake';
-$strFieldsEmpty = ' Sarakkeiden mr on nolla! ';
 $strFieldsEnclosedBy = 'Sarakkeiden ymprintimerkki';
 $strFieldsEscapedBy = 'Koodinvaihtomerkki (escape)';
 $strFields = 'Sarakkeet';
@@ -341,7 +335,6 @@ $strHasBeenCreated = 'on luotu.';
 $strHaveToShow = 'Valitse vhintn yksi sarake';
 $strHebrew = 'Hebrealainen';
 $strHelp = 'Ohje';
-$strHexForBinary = 'Nyt binrikentt heksalukuina';
 $strHide         = 'Ktke';
 $strHideShowAll = 'Ktke/nyt kaikki';
 $strHideShowNoRelation = 'Ktke/nyt taulut, joilla ei ole relaatiota';
@@ -350,9 +343,7 @@ $strHomepageOfficial = 'phpMyAdminin kotisivut';
 $strHostEmpty = 'Palvelimen nimi puuttuu!';
 $strHost = 'Palvelin';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 -viennin valinnat';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 -viennin valinnat';
 $strHungarian = 'Unkarilainen';
 
 $strIcelandic = 'Islantilainen';
@@ -372,10 +363,7 @@ $strIndexHasBeenDropped = 'Indeksi %s on pudotettu';
 $strIndex = 'Indeksi';
 $strIndexName = 'Indeksin nimi:';
 $strIndexType = 'Indeksin tyyppi:';
-$strIndexWarningMultiple = 'Useampi kuin yksi %s-avain luotiin sarakkeelle `%s`';
-$strIndexWarningPrimary = 'PRIMARY- ja INDEX-avaimia ei voi molempia asettaa sarakkeelle `%s`';
 $strIndexWarningTable = 'Taulun `%s` indeksien kanssa on ongelmia';
-$strIndexWarningUnique = 'UNIQUE- ja INDEX-avaimia ei voi molempia asettaa sarakkeelle `%s`';
 $strInnoDBAutoextendIncrement = "Automaattisen laajentamisen koko";
 $strInnoDBAutoextendIncrementDesc = "Laajentamiskoko automaattisesti suurenevan taulutilan koon laajentamiseksi sen tyttyess.";
 $strInnoDBBufferPoolSizeDesc = 'Kertoo koon siit muistipuskurista, jota InnoDB kytt taulujen tietojen ja indeksien siirtmiseen vlimuistiin.';
@@ -424,7 +412,6 @@ $strKnownExternalBug = 'Toimintoon %s vaikuttaa tunnettu vika, katso %s';
 $strKorean = 'Korealainen';
 
 $strLandscape = 'Landscape';
-$strLanguageFileNotFound = 'Kielitiedostoa "%1$s" ei lydy.';
 $strLanguage = 'Kieli';
 $strLanguageUnknown = 'Tuntematon kieli: %1$s.';
 $strLatchedPages = "Lukitut sivut";
@@ -435,11 +422,9 @@ $strLatexContinued = '(jatkuu)';
 $strLatexIncludeCaption = 'Sisllyt taulun otsikko';
 $strLatexLabel = 'Tunniste';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX-valinta-asetukset';
 $strLatexStructure = 'Taulun __TABLE__ rakenne';
 $strLatvian = 'Latvialainen';
 $strLDI = 'CSV kytten LOAD DATA -kysely';
-$strLDIImportOptions = 'Valinnat CSV-tuonnille kytten LOAD DATA -kysely';
 $strLDILocal = 'Kyt LOCAL-avainsanaa';
 $strLengthSet = 'Pituus/Arvot*';
 $strLimitNumRows = 'Rivej sivua kohti';
@@ -542,13 +527,12 @@ $strNumTables = 'Taulut';
 
 $strOK = 'Kunnossa';
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet -valinnat';
 $strOpenDocumentText = 'Open Document Text';
-$strOpenDocumentTextOptions = 'Open Document Text -valinnat';
 $strOpenNewWindow = 'Avaa uusi phpMyAdmin-ikkuna';
 $strOperations = 'Toiminnot';
 $strOperator = 'Operaattori';
 $strOptimizeTable = 'Optimoi taulu';
+$strOptions = 'Valinnat';
 $strOr = 'Tai';
 $strOverhead = 'Ylijm';
 $strOverwriteExisting = 'Korvaa jo olemassaoleva(t) tiedosto(t)';
@@ -566,7 +550,6 @@ $strPassword = 'Salasana';
 $strPdfDbSchema = 'Kaavio tietokannasta "%s" - Sivu %s';
 $strPdfInvalidTblName = 'Taulua "%s" ei lydy!';
 $strPdfNoTables = 'Ei tauluja';
-$strPDFOptions = 'PDF-valinnat';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Luo raportin, joka sislt yksittisen taulun tiedot)';
 $strPDFReportTitle = 'Raportin otsikko';
@@ -732,6 +715,7 @@ $strServerTabVariables = 'Muuttujat';
 $strServerTrafficNotes = '<b>Palvelinliikenne</b>: Nm taulukot nyttvt tmn MySQL-palvelimen verkkoliikennetilastot kynnistyksest lhtien.';
 $strServerVars = 'Palvelimen muuttujat ja asetukset';
 $strServerVersion = 'Palvelimen versio';
+$strSessionStartupErrorGeneral = 'Istuntoa ei voida aloittaa virheitt. Tarkista PHP:n tai verkkopalvelimesi lokitiedostojen antamat virheilmoitukset ja valitse PHP-asennuksen asetukset oikein.';
 $strSessionValue = 'Tmn istunnon arvo';
 $strSetEnumVal = 'Jos sarakkeen tietotyyppi on "enum" tai "set", syt vaaditut arvot tss muodossa: \'a\',\'b\',\'c\'...<br />Jos tarvitset arvoissa kenoviivaa ("\") tai heittomerkki ("\'"), laita merkin eteen kenoviiva (esim. \'\\\\xyz\' tai \'a\\\'b\').';
 $strShowAll = 'Nyt kaikki';
@@ -821,7 +805,7 @@ $strShowStatusKey_readsDescr = 'Kertoo, kuinka monta kertaa levylt on fyysisesti
 $strShowStatusKey_write_requestsDescr = 'Kertoo, kuinka monta kertaa vlimuistiin on kirjoitettu avainlohko.';
 $strShowStatusKey_writesDescr = 'Kertoo, kuinka monta kertaa levylle on fyysisesti kirjoitettu avainlohko.';
 $strShowStatusLast_query_costDescr = 'Viimeksi kootun (compiled) kyselyn kokonaiskulut kyselynoptimoija laskemana. Hydyllinen suunniteltaessa erilaisia kyselyvaihtoehtoja samaa kysely varten. Oletusarvo 0 tarkoittaa, ett yhtn kysely ei ole viel koottu.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Niiden rivien mr, joita odotetaan kirjoitettavan INSERT DELAY -jonoissa.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Niiden rivien mr, joita odotetaan kirjoitettavan INSERT DELAYED -jonoissa.';
 $strShowStatusOpened_tablesDescr = 'Avattujen taulujen mr. Jos mr on suuri, tauluvlimuistin arvo saattaa olla liian alhainen.';
 $strShowStatusOpen_filesDescr = 'Avoinna olevien tiedostojen mr.';
 $strShowStatusOpen_streamsDescr = 'Avoinna olevien voiden mr (kytetn enimmkseen kirjausta varten).';
@@ -876,8 +860,6 @@ $strSpanish = 'Espanjalainen';
 $strSplitWordsWithSpace = 'Sanat erotellaan vlilynnill.';
 $strSQLCompatibility = 'SQL-yhteensopiva tila';
 $strSQLExportType = 'Vientityyppi';
-$strSQLImportOptions = 'SQL-valinnat';
-$strSQLOptions = 'SQL-valinnat';
 $strSQLParserBugMessage = 'Olet mahdollisesti lytnyt ohjelmointivirheen SQL-parserista. Tarkista SQL-lauseesi, erityisesti lainausmerkit merkkijonojen alusta ja lopusta. Toinen mahdollinen virheen aiheuttaja on se, ett olet siirtmss tiedostoa, jossa on binritietoa lainausmerkkien ulkopuolella. Jos mahdollista, kokeile SQL-lausettasi suoraan komentorivilt. MySQL-palvelimen antama virheilmoitus nkyy alla, mikli se sellaisen antoi. Jos lause toimi komentorivilt, mutta ei phpMyAdminista, etsi se rivi jolla virheilmoitus ilmeni ja lhet meille virheraportti, johon liitt alla olevan koodin:';
 $strSQLParserUserError = 'SQL-lauseessasi nytt olevan jokin virhe. MySQL-palvelimen antama virheilmoitus nkyy alla, mikli palvelin sellaisen antoi.';
 $strSQLQuery = 'SQL-kysely';
@@ -899,7 +881,6 @@ $strStrucCSV = 'CSV-muotoista tietoa';
 $strStrucData = 'Rakenne ja tiedot';
 $strStrucExcelCSV = 'MS Excelin CSV-muoto';
 $strStrucNativeExcel = 'Natiivi MS Excel -tieto';
-$strStrucNativeExcelOptions = 'Natiivin Excel-viennin valinnat';
 $strStrucOnly = 'Vain rakenne';
 $strStructPropose = 'Esit taulun rakenne';
 $strStructureForView = 'Nkymn rakenne';
@@ -981,6 +962,13 @@ $strUpdateProfileMessage = 'Profiili on pivitetty.';
 $strUpdateQuery = 'Pivit kysely';
 $strUpdComTab = 'Tarkista dokumentaatiosta, kuinka voit pivitt Column_comments-taulusi';
 $strUpgrade = 'Sinun pitisi pivitt versioon %s %s tai sit myhempn versioon.';
+$strUploadErrorCantWrite = 'Tiedoston kirjoitus levylle eponnistui.';
+$strUploadErrorExtension = 'Laajennus keskeytti tiedoston lhetyksen.';
+$strUploadErrorFormSize = 'Lhetetyn tiedoston koko ylitt HTML-lomakkeessa mritetyn MAX_FILE_SIZE-asetuksen arvon.';
+$strUploadErrorIniSize = 'Lhetyn tidoston koko ylitt php.ini-tiedoston upload_max_filesize-asetuksen arvon.';
+$strUploadErrorNoTempDir = 'Tilapiskansio puuttuu.';
+$strUploadErrorPartial = 'Tiedosto lhetettiin vain osittain.';
+$strUploadErrorUnknown = 'Tuntematon virhe tiedostoa lhetettess.';
 $strUploadLimit = 'Yritit todennkisesti lhett palvelimelle liian suurta tiedostoa. Katso listietoja %sdokumentaatiosta%s tmn rajoituksen muuttamiseksi.';
 $strUploadsNotAllowed = 'Tiedostojen lhetyst ei ole sallittu tll palvelimella.';
 $strUsage = 'Kytt';
@@ -1011,6 +999,7 @@ $strViewDump = 'Tee vedos taulusta';
 $strViewHasBeenDropped = "Nkym %s on poistettu";
 $strViewMaxExactCount = 'Tss nkymss on yli %s rivi. Katso listietoja %sdokumentaatiosta%s.';
 $strView = "Nkym";
+$strViewName = 'VIEW-arvon nimi';
 
 $strWebServerUploadDirectoryError = 'Valitsemaasi hakemistoa ei voitu kytt tiedostojen siirtmiseen';
 $strWebServerUploadDirectory = 'palvelimen hakemisto tiedostojen siirtoa varten';
@@ -1022,7 +1011,6 @@ $strWithChecked = 'Valitut:';
 $strWriteRequests = 'Kirjoituspyynnt';
 $strWrongUser = 'Vr kyttjtunnus tai salasana. Psy kielletty.';
 
-$strXMLOptions = 'XML-valinnat';
 $strXML = 'XML';
 
 $strYes = 'Kyll';
@@ -1030,4 +1018,16 @@ $strYes = 'Kyll';
 $strZeroRemovesTheLimit = 'Huom: Niden valintojen asettaminen nollaksi (0) poistaa rajoituksen.';
 $strZip = '"zip-pakattu"';
 
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
