@@ -1,11 +1,11 @@
 <?php
-/* $Id: lithuanian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: lithuanian-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$number_thousands_separator = ',';
-$number_decimal_separator = '.';
+$number_thousands_separator = ' ';
+$number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 
@@ -58,7 +58,6 @@ $strAscending = 'Didėjimo tvarka';
 $strAtBeginningOfTable = 'Lentelės pradžioje';
 $strAtEndOfTable = 'Lentelės pabaigoje';
 $strAttr = 'Atributai';
-$strAutodetect = 'Automatinis nustatymas';
 $strAutomaticLayout = 'Automatinis išdėstymas';
 
 $strBack = 'Atgal';
@@ -151,7 +150,6 @@ $strCreate = 'Sukurti';
 $strCreationDates = 'Sukūrimo/Atnaujinimo/Peržiūros datos';
 $strCriteria = 'Kriterijai';
 $strCroatian = 'Kroatų';
-$strCSVOptions = 'CSV parinktys';
 $strCyrillic = 'Kirylica';
 $strCzech = 'Čekų';
 $strCzechSlovak = 'Čekų-Slovakų';
@@ -161,7 +159,6 @@ $strDatabase = 'Duombazė';
 $strDatabaseEmpty = 'Nenurodytas duombazės vardas!';
 $strDatabaseExportOptions = 'Duombazės eksportavimo parinktys';
 $strDatabaseHasBeenDropped = 'Duombazė %s ištrinta.';
-$strDatabaseNoTable = 'Ši duombazė lentelių neturi!';
 $strDatabasesDropped = 'Sėkmingai pašalintos %s duombazės.';
 $strDatabases = 'duombazės';
 $strDatabasesStatsDisable = 'Leisti statistiką';
@@ -227,7 +224,6 @@ $strError = 'Klaida';
 $strEscapeWildcards = 'Norint naudoti _ ir % simblius, juos reikėtų eskeipinti su \\';
 $strEstonian = 'Estų'; 
 $strExcelEdition = 'Excel variantas';
-$strExcelOptions = 'Excel parinktys';
 $strExecuteBookmarked = 'Įvykdyti išsaugotą užklausą';
 $strExplain = 'Paaiškinti';
 $strExport = 'Eksportuoti';
@@ -237,7 +233,6 @@ $strExtra = 'Papildomai';
 $strFailedAttempts = 'Nepavykę bandymai';
 $strFieldHasBeenDropped = 'Laukas %s išmestas';
 $strField = 'Laukas';
-$strFieldsEmpty = ' Tuščia laukų skaičiaus reikšmė! ';
 $strFieldsEnclosedBy = 'Laukų reikšmės apskliaustos  simboliais';
 $strFieldsEscapedBy = 'Laukų reikšmės baigiasi simboliu';
 $strFields = 'Lauką';
@@ -273,15 +268,12 @@ $strHasBeenAltered = 'išplėsta.';
 $strHasBeenCreated = 'sukurta.';
 $strHaveToShow = 'Pasirinkite bent vieną stulpelį išvedimui';
 $strHebrew = 'Žydų';
-$strHexForBinary = 'Binariniams laukams naudoti šešioliktainę koduotę';
 $strHomepageOfficial = 'Oficialus phpMyAdmin tinklapis';
 $strHome = 'Pradinis';
 $strHost = 'Darbinė stotis';
 $strHostEmpty = 'Tuščias prisijungimo adresas!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 exportavimo parinktys';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 exportavimo parinktys';
 $strHungarian = 'Vengrų';
 
 $strIcelandic = 'Islandų';
@@ -295,10 +287,7 @@ $strIndexHasBeenDropped = 'Indeksas %s panaikintas';
 $strIndex = 'Indeksas';
 $strIndexName = 'Indekso vardas&nbsp;:';
 $strIndexType = 'Indekso tipas&nbsp;:';
-$strIndexWarningMultiple = 'Daugiau nei vienas %s raktas buvo nustatytas stulpeliui `%s`';
-$strIndexWarningPrimary = 'PRIMARY ir INDEX raktai neutrėtų būti nustatomi tam pačiam `%s` stulpeliui';
 $strIndexWarningTable = 'Iškilo problemos su `%s` lentelės indeksais';
-$strIndexWarningUnique = 'UNIQUE ir INDEX raktai neutrėtų būti nustatomi tam pačiam `%s` stulpeliui';
 $strInnoDBBufferPoolSize = 'Buferio pool\'o dydis';
 $strInnoDBDataFilePath = 'Duomenų failai'; 
 $strInnoDBDataHomeDirDesc = 'Bendra direktorijų kelio dalis visiems InnoDB duomenų failams.';
@@ -330,7 +319,6 @@ $strLatexContinued = '(tęsinys)';
 $strLatexIncludeCaption = 'Įterpti lentelės antraštę';
 $strLatexLabel = 'Pavadinimo raktas';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX nustatymai';
 $strLatexStructure = 'Lentelės __TABLE__ struktūra';
 $strLatvian = 'Latvių';
 $strLengthSet = 'Ilgis/reikšmės*';
@@ -603,7 +591,6 @@ $strSpaceUsage = 'Vietos naudojimas';
 $strSpanish = 'Ispanų';
 $strSplitWordsWithSpace = 'Žodžiai atskirti tarpo simboliu (" ").';
 $strSQLExportType = 'Eksporto tipas';
-$strSQLOptions = 'SQL nustatymai';
 $strSQLParserBugMessage = 'Klaidą SQL interpretatoriuje. Prašome patikrinti  ar SQL užklausoje teisingai naudojamos kabutės. Kita, galima klaida, jog Jūs bandote atsiųsti dvejetainius (binary) duomenis neapskliaustus kabutėmis. Taip pat Jūs galite pabandyti įvykdyti savo užklausą iš MySQL konsolės. MySQL serverio išvesta informacija apie klaidą (jeigu tokių bus) gali padėti Jums nustatyti klaidos priežastį. Jeigu užklausa sėkmingai įvykdoma konsolėje, o SQL interpretatorius vistiek išveda pranešimus apie klaidas, prašome supaprastinite savo SQL užklausą ir perduodamų duomenų kiekį užklausoje ir praneškite apie klaidą programos kūrėjams su žemiau pateikiama informacija:';
 $strSQLParserUserError = 'Klaida SQL užklausoje. Žemiau išvestas MySQL serverio pranešimas (jeigu toks yra), turėtų padėti Jums nustatyti klaidos priežastį';
 $strSQLQuery = 'SQL užklausa';
@@ -745,7 +732,6 @@ $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
@@ -792,11 +778,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 
 $strMaxConnects = 'max. concurrent connections';  //to translate
@@ -816,7 +800,6 @@ $strOperator = 'Operator';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -908,7 +891,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -946,7 +929,6 @@ $strShowStatusThreads_runningDescr = 'The number of threads that are not sleepin
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 
 $strTableAlreadyExists = 'Table %s already exists!';  //to translate
@@ -974,16 +956,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -999,7 +977,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1044,4 +1021,27 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
