@@ -1,7 +1,7 @@
 <?php
-/* $Id: spanish-iso-8859-15.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: spanish-iso-8859-1.inc.php 11212 2008-04-23 16:28:20Z lem9 $ */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
@@ -64,7 +64,6 @@ $strAscending = 'Ascendente';
 $strAtBeginningOfTable = 'Al comienzo de la tabla';
 $strAtEndOfTable = 'Al final de la tabla';
 $strAttr = 'Atributos';
-$strAutodetect = 'Autodetectar';
 $strAutomaticLayout = 'Diseo automtico';
 
 $strBack = 'Volver';
@@ -153,6 +152,7 @@ $strConnectionError = 'No se estableci la conexin: los parmetros estn incorrecto
 $strConnections = 'Conexiones';
 $strConstraintsForDumped = 'Filtros para las tablas descargadas (dump)';
 $strConstraintsForTable = 'Filtros para la tabla';
+$strControluserFailed = 'La conexin para controluser, como est definida en su configuracin, fracas.';
 $strCookiesRequired = 'Las "cookies" deben estar habilitadas.';
 $strCopy = 'Copiar';
 $strCopyDatabaseOK = 'La base de datos %s ha sido copiada a %s';
@@ -178,8 +178,6 @@ $strCreationDates = 'Fechas de creacin/actualizacin/revisin';
 $strCriteria = 'Criterio';
 $strCroatian = 'Croata';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opciones CSV';
-$strCSVOptions = 'Opciones CSV';
 $strCyrillic = 'Cirlico';
 $strCzech = 'Checo';
 $strCzechSlovak = 'Checo-Eslovaco';
@@ -189,7 +187,6 @@ $strDatabase = 'Base de datos';
 $strDatabaseEmpty = 'El nombre de la base de datos est vaco!';
 $strDatabaseExportOptions = 'Opciones de exportacin de la base de datos';
 $strDatabaseHasBeenDropped = 'La base de datos %s ha sido eliminada.';
-$strDatabaseNoTable = 'Esta base de datos no contiene tablas!';
 $strDatabases = 'Bases de datos';
 $strDatabasesDropped = '%s bases de datos han sido eliminadas exitosamente.';
 $strDatabasesStatsDisable = 'Desactivar las estadsticas';
@@ -235,7 +232,6 @@ $strDisplayOrder = 'Mostrar en este orden:';
 $strDisplayPDF = 'Mostrar esquema PDF';
 $strDoAQuery = 'Hacer una consulta (comodn: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Opciones DocSQL';
 $strDocu = 'Documentacin';
 $strDoYouReally = 'Realmente desea ';
 $strDropDatabaseStrongWarning = 'Est a punto de DESTRUIR una base de datos completa!';
@@ -272,8 +268,8 @@ $strErrorSaveTable = 'Error guardando las coordenadas para el Diseador.';
 $strEscapeWildcards = 'Los comodines _ y % deben acompaarse de \ para usarlos de manera literal';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonio';
+$strEvent = 'Evento';
 $strExcelEdition = 'Edicin Excel';
-$strExcelOptions = 'Opciones de Excel';
 $strExecuteBookmarked = 'Ejecute la consulta marcada previamente';
 $strExplain = 'Explicar el SQL';
 $strExport = 'Exportar';
@@ -285,8 +281,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Intentos fallidos';
 $strField = 'Campo';
 $strFieldHasBeenDropped = 'Se elimin el campo %s';
+$strFieldInsertFromFileTempDirNotExists = 'Se detect un error al trasladar el archivo cargado, ver FAQ 1.11';
 $strFields = 'Campos';
-$strFieldsEmpty = 'El nmero de campos est vaco!';
 $strFieldsEnclosedBy = 'Campos encerrados por';
 $strFieldsEscapedBy = 'Caracter de escape';
 $strFieldsTerminatedBy = 'Campos terminados en';
@@ -298,6 +294,7 @@ $strFileNameTemplateDescriptionServer = 'nombre del servidor';
 $strFileNameTemplateDescriptionTable = 'nombre de la tabla';
 $strFileNameTemplate = 'Plantilla del nombre del archivo';
 $strFileNameTemplateRemember = 'recordar la plantilla';
+$strFiles = 'Archivos';
 $strFileToImport = 'Archivo a importar';
 $strFixed = 'fijo';
 $strFlushPrivilegesNote = 'Nota: phpMyAdmin obtiene los privilegios de los usuarios \'directamente de las tablas de privilegios MySQL\'. El contenido de estas tablas puede diferir de los privilegios que usa el servidor si es que se han realizado cambios manuales en l. En este caso, nuevamente deber %scargar la pgina de privilegios%s antes de continuar.';
@@ -334,7 +331,7 @@ $strHasBeenCreated = 'se cre.';
 $strHaveToShow = 'Debe elegir al menos una columna para mostrar';
 $strHebrew = 'Hebreo';
 $strHelp = 'Ayuda';
-$strHexForBinary = 'Usar hexadecimal para campos binarios';
+$strHexForBLOB = 'Use hexadecimal para BLOB';
 $strHide         = 'Ocultar';
 $strHideShowAll = 'Ocultar/mostrar todo';
 $strHideShowNoRelation = 'Ocultar/mostrar Tablas que no tengan relacin';
@@ -343,9 +340,7 @@ $strHome = 'Pgina de inicio';
 $strHostEmpty = 'El nombre del servidor est vaco!!';
 $strHost = 'Servidor';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opciones de exportacin Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opciones de exportacin Microsoft Word 2000';
 $strHungarian = 'Hngaro';
 
 $strIcelandic = 'Islands';
@@ -361,14 +356,12 @@ $strImportFormat = 'Formato del archivo importado';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'La importacin se ejecut exitosamente, se ejecutaron %d consultas.';
 $strIndexes = 'ndices';
+$strIndexesSeemEqual = 'Los siguientes ndices parecen ser idnticos y uno de ellos debe ser removido:';
 $strIndexHasBeenDropped = 'El ndice %s ha sido eliminado';
 $strIndex = 'ndice';
 $strIndexName = 'Nombre del ndice&nbsp;:';
 $strIndexType = 'Tipo de ndice&nbsp;:';
-$strIndexWarningMultiple = 'Se cre ms de una clave %s para la columna `%s`';
-$strIndexWarningPrimary = 'Las claves PRIMARIA e NDICE no deben seleccionarse juntas para la columna `%s`';
 $strIndexWarningTable = 'Problemas con los ndices de la tabla `%s`';
-$strIndexWarningUnique = 'Las claves UNICA e NDICE no deben seleccionarse juntas para la columna `%s`';
 $strInnoDBAutoextendIncrementDesc = 'El tamao a incrementar para que se extienda el ancho de una tabla capaz de autoextenderse cuando se llena.'; 
 $strInnoDBAutoextendIncrement = 'Incremente el valor AUTOEXTEND'; 
 $strInnoDBBufferPoolSizeDesc = 'El tamao de la memoria intermedia (bfer) usado por InnoDB para almacenar, en el cache, los datos e ndices de sus tablas.';
@@ -417,7 +410,6 @@ $strKnownExternalBug = 'La funcionalidad %s est afectada por un fallo conocido,
 $strKorean = 'Coreano';
 
 $strLandscape = 'Orientacin horizontal';
-$strLanguageFileNotFound = 'No se hall el archivo de idioma "%1$s".';
 $strLanguage = 'Idioma';
 $strLanguageUnknown = 'Idioma desconocido: %1$s.';
 $strLatchedPages = 'Pginas vinculadas';
@@ -428,11 +420,9 @@ $strLatexContinued = '(contina)';
 $strLatexIncludeCaption = 'Incluir el subtitulado de la tabla';
 $strLatexLabel = 'Clave de la etiqueta';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'opciones LaTeX';
 $strLatexStructure = 'Estructura de la tabla __TABLE__';
 $strLatvian = 'Letn';
 $strLDI = 'CSV usando LOAD DATA';
-$strLDIImportOptions = 'Las opciones para la importacin CSV usando LOAD DATA';
 $strLDILocal = 'Use la palabra clave LOCAL';
 $strLengthSet = 'Longitud/Valores*';
 $strLimitNumRows = 'registros por pgina';
@@ -489,6 +479,7 @@ $strMyISAMSortBufferSize = 'Organizar el tamao del bfer de memoria';
 $strMySQLCharset = 'Juegos de caracteres de MySQL';
 $strMysqlClientVersion = 'Versin del cliente';
 $strMySQLConnectionCollation = 'Cotejamiento de las conexiones MySQL';
+$strMysqlLibDiffersServerVersion = 'Su versin de librera PHP MySQL  %s es distinta de aquella de su versin de servidor MySQL %s. Esto puede ocasionar un comportamiento impredecible.';
 $strMySQLSaid = 'MySQL ha dicho: ';
 $strMySQLShowProcess = 'Mostrar procesos';
 $strMySQLShowStatus = 'Mostrar informacin de tiempo de ejecucin de MySQL';
@@ -535,13 +526,12 @@ $strNumTables = 'Tablas';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'Hoja de clculo Open Document';
-$strOpenDocumentSpreadsheetOptions = 'Opciones de la hoja de clculo Open Document';
-$strOpenDocumentTextOptions = 'Opciones del texto Open Document';
 $strOpenDocumentText = 'Texto Open Document';
 $strOpenNewWindow = 'Abrir nueva ventana de phpMyAdmin';
 $strOperations = 'Operaciones';
 $strOperator = 'Operador';
 $strOptimizeTable = 'Optimizar la tabla';
+$strOptions = 'Opciones';
 $strOr = 'O';
 $strOverhead = 'Residuo a depurar';
 $strOverwriteExisting = 'Sobreescribir el(los) archivo(s) existente(s)';
@@ -559,7 +549,6 @@ $strPasswordNotSame = 'Las contraseas no coinciden!';
 $strPdfDbSchema = 'Esquema de la base de datos "%s" - Pgina %s';
 $strPdfInvalidTblName = 'La tabla "%s" no existe!';
 $strPdfNoTables = 'No existen tablas';
-$strPDFOptions = 'Opciones del PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Genera un reporte conteniendo los datos de una sola tabla)';
 $strPDFReportTitle = 'Ttulo del reporte';
@@ -627,6 +616,7 @@ $strPrivilegesReloaded = 'Los privilegios fueron cargados nuevamente de manera e
 $strProcedures = 'Procedimientos';
 $strProcesses = 'Procesos';
 $strProcesslist = 'Lista de procesos';
+$strProfiling = 'Perfil/Perfilamiento';
 $strProtocolVersion = 'Versin del protocolo';
 $strPutColNames = 'Poner los nombres de campo en la primera hilera';
 
@@ -668,12 +658,15 @@ $strReplaceTable = 'Reemplazar los datos de la tabla con los del archivo';
 $strReplication = 'Replicacin';
 $strReset = 'Reiniciar';
 $strResourceLimits = 'Lmites de recursos';
+$strRestartInsertion = 'Reinicie la insercin con %s filas';
 $strReType = 'Debe volver a escribir';
 $strRevokeAndDeleteDescr = 'Los usuarios an tendrn el privilegio "USAGE" hasta que los privilegios se hayan vuelto a cargar.';
 $strRevokeAndDelete = 'Revocar todos los privilegios activos de los usuarios y borrarlos despus.';
 $strRevokeMessage = 'Ha revocado los privilegios para %s';
 $strRevoke = 'Revocar';
 $strRomanian = 'Rumano';
+$strRoutineReturnType = 'Muestre el tipo';
+$strRoutines = 'Rutinas';
 $strRowLength = 'Longitud de la fila';
 $strRows = 'Filas';
 $strRowsFrom = 'filas empezando de';
@@ -725,6 +718,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Trfico del servidor</b>: Estas tablas muestran las estadsticas de trfico en la red de este servidor MySQL desde su inicio.';
 $strServerVars = 'Variables y parmetros del servidor';
 $strServerVersion = 'Versin del servidor';
+$strSessionStartupErrorGeneral = 'Hubo errores al iniciar la sesin.  Por favor, revise los errores en la bitcora de su PHP y/o servidor web y configure correctamente su instalacin PHP.';
 $strSessionValue = 'Valor de la sesin';
 $strSetEnumVal = 'Si el tipo de campo es "enum" o "set", por favor ingrese los valores usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez necesita poner una barra invertida("\") o una comilla simple ("\'") entre esos valores, siempre ponga una barra invertida. (Por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
 $strShowAll = 'Mostrar todo';
@@ -814,7 +808,7 @@ $strShowStatusKey_readsDescr = 'El nmero de lecturas fsicas del key block desde
 $strShowStatusKey_write_requestsDescr = 'El nmero de solicitudes para escribir un key block al cache.';
 $strShowStatusKey_writesDescr = 'El nmero de escrituras fsicas a un key block al disco.';
 $strShowStatusLast_query_costDescr = 'El costo total de la ltima consulta compilada como fuera computada por el optimizador de consultas. Es til para comparar el costo de diferentes planes de consulta para una misma consulta. El valor por omisin de 0 significa que ninguna consulta ha sido compilada todava.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'El nmero de filas esperando ser escritas en las colas INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'El nmero de filas esperando ser escritas en las colas INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'El nmero de tablas que han sido abiertas. Si el nmero de tablas abiertas es grande, su valor del cache de tabla probablemente es muy pequeo.';
 $strShowStatusOpen_filesDescr = 'El nmero de archivos que estn abiertos.';
 $strShowStatusOpen_streamsDescr = 'El nmero de flujos de datos que estn abiertos (usado principalmente para alimentar a los logs).';
@@ -869,8 +863,6 @@ $strSpanish = 'Espaol';
 $strSplitWordsWithSpace = 'Palabras separadas por un espacio (" ").';
 $strSQLCompatibility = 'Modalidad compatible con SQL';
 $strSQLExportType = 'Tipo de exportacin';
-$strSQLImportOptions = 'Opciones SQL';
-$strSQLOptions = 'Opciones SQL';
 $strSQLParserBugMessage = 'Hay la posibilidad de que usted haya encontrado un error en el intrprete de SQL. Por favor examine cuidadosamente su consulta, y verifique que las comillas estn siendo usadas adecuadamente y hacen juego. Otra posible causa del fallo es que usted este subiendo un archivo con datos binarios por fuera del rea de texto delimitado. Intente su consulta en la interfaz de comandos de MySQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema. Si an tiene problemas o el intrprete falla en tanto que en la interfaz de comandos funciona, por favor reduzca la salida de su consulta de SQL a la consulta que genera el problema, y enve un reporte de error con la cadena de datos en la seccin de CORTE indicada abajo:';
 $strSQLParserUserError = 'Parece haber un error en su consulta de SQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema.';
 $strSQLQuery = 'consulta SQL';
@@ -892,13 +884,13 @@ $strStrucCSV = 'Datos CSV ';
 $strStrucData = 'Estructura y datos';
 $strStrucExcelCSV = 'CSV para datos de MS Excel';
 $strStrucNativeExcel = 'Datos de MS Excel en formato nativo';
-$strStrucNativeExcelOptions = 'Opciones de exportacin nativas para Excel';
 $strStrucOnly = 'nicamente la estructura ';
 $strStructPropose = 'Planteamiento de la estructura de tabla';
 $strStructure = 'Estructura';
 $strStructureForView = 'Estructura para la vista';
 $strSubmit = 'Enviar';
 $strSuccess = 'Su consulta se ejecut con xito';
+$strSuhosin = 'El servidor est utilizando Suhosin. Por favor, refirase a %sdocumentation%s para posibles ajustes.';
 $strSum = 'Nmero de filas';
 $strSwedish = 'Sueco';
 $strSwitchToDatabase = 'Seleccionar la base de datos copiada';
@@ -958,6 +950,7 @@ $strTransformation_text_plain__imagelink = 'Muestra una imagen y un enlace, el c
 $strTransformation_text_plain__link = 'Muestra un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es un ttulo para el enlace.';
 $strTransformation_text_plain__sql = 'Formatea el texto como una consulta SQL y resalta la sintaxis.';
 $strTransformation_text_plain__substr = 'Muestra una parte de una cadena de caracteres. La primera opcin es el nmero de caracteres a pasar por alto desde el principio de la cadena de caracteres (Predeterminado: 0). La segunda opcin es el nmero de caracteres a mostrar (Predeterminado: hasta el final de la cadena de caracteres). La tercera opcin es la cadena de caracteres a adjuntar y/o anteponer cuando haya truncamiento (Predeterminado: "...").';
+$strTriggers = '(Evento) desencadenante';
 $strTruncateQueries = 'Truncar las consultas que ya se han mostrado';
 $strTurkish = 'Turco';
 $strType = 'Tipo';
@@ -974,6 +967,13 @@ $strUpdateProfileMessage = 'Se actualiz el perfil.';
 $strUpdateQuery = 'Modificar la consulta';
 $strUpdComTab = 'Para actualizar su tabla Columna_comentarios (Column_comments), por favor revise la documentacin';
 $strUpgrade = 'Usted debera actualizar su %s a la versin %s o ms reciente.';
+$strUploadErrorCantWrite = 'No fue posible grabar el archivo al disco.';
+$strUploadErrorExtension = 'La carga del archivo fue detenida por extensin.';
+$strUploadErrorFormSize = 'El archivo que intent cargar excede la directiva MAX_FILE_SIZE especificada en el formulario HTML.';
+$strUploadErrorIniSize = 'El archivo que intent cargar excede la directiva upload_max_filesize en php.ini.';
+$strUploadErrorNoTempDir = 'No existe una carpeta temporal.';
+$strUploadErrorPartial = 'El archivo que intent cargar no alcanz el 100%.';
+$strUploadErrorUnknown = 'Error desconocido durante la carga del archivo.';
 $strUploadLimit = 'Usted probablemente intent cargar un archivo demasiado grande.  Por favor, refirase a %sdocumentation%s para hallar modos de superar esta limitante.';
 $strUploadsNotAllowed = 'No est permitido subir archivos a este servidor.';
 $strUsage = 'Uso';
@@ -1003,6 +1003,7 @@ $strViewDumpDB = 'Ver el volcado esquema de la base de datos';
 $strViewDump = 'Mostrar el volcado esquema de la tabla';
 $strViewHasBeenDropped = 'Se descart el modo de visualizacin %s';
 $strViewMaxExactCount = 'Esta visualizacin tiene ms de %s filas. Por favor, refirase a la %sdocumentacin%s.';
+$strViewName = '(VIEW) VER nombre';
 $strView = 'Visualizar';
 
 $strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
@@ -1015,7 +1016,6 @@ $strWithChecked = 'Para los elementos que estn marcados:';
 $strWriteRequests = 'Escribir las solicitudes';
 $strWrongUser = 'El nombre de usuario o la contrasea est equivocado. El acceso fue denegado.';
 
-$strXMLOptions = 'Opciones XML';
 $strXML = 'XML';
 
 $strYes = 'S';
