@@ -1,11 +1,11 @@
 <?php
-/* $Id: turkish-iso-8859-9.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
+/* $Id: turkish-iso-8859-9.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 // phpMyAdmin Trke 01.09.2006 itibariyle nceki eviriye gre ok daha 
 // iyi bir eviriyle yeniden yaplmtr. 
 // Birim ayarlar Trke standartlarna gre tam ve doru olarak ayarlanmtr.
 // eviren Burak Yavuz (BouRock@live.com)
-// eviri srm phpMyAdmin 2.9.0.0 ve zeri srmlere uygundur.
+// eviri srm phpMyAdmin 2.10.1.0
 
 $charset = 'iso-8859-9';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
@@ -28,8 +28,8 @@ $datefmt = '%d %B %Y saat %H:%M:%S';
 $timespanfmt = '%s gn, %s saat, %s dakika ve %s saniye';
 
 $strAbortedClients = 'ptal edilen';
-$strAccessDeniedCreateConfig = 'Muhtemelen bunun sebebi yaplandrma dosyasn oluturmadnz. Bir tane oluturmak iin %1$ssetup script%2$s kullanmak isteyebilirsiniz.';
 $strAccessDenied = 'Eriim engellendi';
+$strAccessDeniedCreateConfig = 'Muhtemelen bunun sebebi yaplandrma dosyasn oluturmadnz iindir. Bir tane oluturmak iin %1$skurulum programc%2$s kullanmak isteyebilirsiniz.';
 $strAccessDeniedExplanation = 'phpMyAdmin MySQL sunucusuna balanmay denedi ama sunucu balanty reddetti. config.inc iindeki anamakine (host) adresini, kullanc adn ve parolay kontrol edin ve MySQL sunucusunun yneticisi tarafndan verilen bilgiyle uyutuundan emin olun.';
 $strAction = 'Eylem';
 $strAddAutoIncrement = 'AUTO_INCREMENT deeri ekle';
@@ -38,7 +38,7 @@ $strAddConstraints = 'Kstlamalar ekle';
 $strAddDeleteColumn = 'Alan Stunlar Ekle/Sil';
 $strAddDeleteRow = 'Kriter Satr Ekle/Sil';
 $strAddFields = '%s alan ekle';
-$strAddHeaderComment = 'Balk iine zel yorum ekle (\\n satr bler)';
+$strAddHeaderComment = 'Balk iine zel yorum ekle (\\n satrlar bler)';
 $strAddIntoComments = 'Yorumlarn iine ekle';
 $strAddNewField = 'Yeni alan ekle';
 $strAddPrivilegesOnDb = 'Aadaki veritabanna yetkileri ekle';
@@ -74,7 +74,6 @@ $strAscending = 'Kkten Bye';
 $strAtBeginningOfTable = 'Tablonun Banda';
 $strAtEndOfTable = 'Tablonun Sonunda';
 $strAttr = 'znitelikler';
-$strAutodetect = 'Otomatik Sapta';
 $strAutomaticLayout = 'Otomatik yerleim';
 
 $strBack = 'Geri';
@@ -120,7 +119,7 @@ $strCanNotLoadImportPlugins = 'eri aktarma eklentileri yklenemedi, ltfen kurulum
 $strCannotLogin = 'MySQL sunucusuna oturum alamyor';
 $strCantLoad = '[a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] uzants yklenemiyor. Ltfen PHP yaplandrmanz kontrol edin.';
 $strCantLoadRecodeIconv = 'Karakter grubu dnm iin gerekli olan iconv veya recode uzantlar yklenemedi. Ya PHP\'yi bu uzantlar etkinletirmek iin yaplandrn ya da phpMyAdmin iinde karakter grubu dnmn etkisizletirin...';
-$strCantRenameIdxToPrimary = 'ndeks\'i PRIMARY olarak yeniden adlandrmazsnz!';
+$strCantRenameIdxToPrimary = 'ndeks\'i PRIMARY olarak yeniden adlandramazsnz!';
 $strCantUseRecodeIconv = 'Gerekli uzantlar yklenmi grnmesine ramen, ne iconv, ne libinconv, ne de recode_string ilevi kullanlamad. PHP yaplandrmanz kontrol edin.';
 $strCardinality = 'nemlilik';
 $strCaseInsensitive = 'byk kk harfe duyarsz';
@@ -163,6 +162,7 @@ $strConnectionError = 'Balanamyor: geersiz ayarlar.';
 $strConnections = 'Balantlar';
 $strConstraintsForDumped = 'Dkm yaplm tablolar iin kstlamalar';
 $strConstraintsForTable = 'Tablo kstlamalar';
+$strControluserFailed = 'Yaplandrmanz iinde tanmlanm denetim kullanclar iin balant baarsz.';
 $strCookiesRequired = 'Bu ksm gemek iin tanmlama bilgileri (Cookies) ak olmal.';
 $strCopyDatabaseOK = '%s veritaban %s\'e kopyaland.';
 $strCopy = 'Kopyala';
@@ -188,8 +188,6 @@ $strCreationDates = 'Oluturma/Gncelleme/Kontrol tarihleri';
 $strCriteria = 'Kriter';
 $strCroatian = 'Hrvata';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV seenekleri';
-$strCSVOptions = 'CSV seenekleri';
 $strCyrillic = 'Kiril';
 $strCzech = 'eke';
 $strCzechSlovak = 'eke-Slovaka';
@@ -198,7 +196,6 @@ $strDanish = 'Danca';
 $strDatabaseEmpty = 'Veritaban ad bo!';
 $strDatabaseExportOptions = 'Veritaban dar aktarma seenekleri';
 $strDatabaseHasBeenDropped = '%s veritaban kaldrld.';
-$strDatabaseNoTable = 'Bu veritaban tablo iermiyor!';
 $strDatabasesDropped = '%s veritabanlar baarl olarak kaldrld.';
 $strDatabasesStatsDisable = 'statistikler etkisiz';
 $strDatabasesStatsEnable = 'statistikler etkin';
@@ -234,6 +231,7 @@ $strDelOld = 'u anki sayfa, daha fazla bulunmas gereksiz tablolara verilmi refer
 $strDescending = 'Bykten Ke';
 $strDescription = 'Aklama';
 $strDesigner = 'Tasarmc';
+$strDesignerHelpDisplayField = 'Grnt alan pembe ile gsterilir. Alan, grnt alan olarak ayarlamak/ayar kaldrmak iin "Grntlemek iin alan se" simgesine tklayn, sonrada uygun alan ad zerine tklayn.';
 $strDictionary = 'szlk';
 $strDirectLinks = 'Dorudan balantlar';
 $strDirtyPages = 'Bozuk sayfalar';
@@ -244,9 +242,8 @@ $strDisplayOrder = 'Grnm dzeni:';
 $strDisplayPDF = 'PDF emasn gster';
 $strDoAQuery = '"rnek sorgu" yap. (joker: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL seenekleri';
 $strDocu = 'Belgeler';
-$strDoYouReally = 'Aadaki komutu uygulamak istediinizden emin misiniz? ';
+$strDoYouReally = 'Aadaki komutu uygulamak istediinize emin misiniz? ';
 $strDropDatabaseStrongWarning = 'Btn bir veritabann YOK ETMEK zeresiniz!';
 $strDrop = 'Kaldr';
 $strDropUsersDb = 'Kullanclarla ayn isimlerde olan veritabanlarn kaldr.';
@@ -281,8 +278,8 @@ $strErrorSaveTable = 'Tasarmc dzenlemelerini kaydetme hatas.';
 $strEscapeWildcards = '_ ve % jokerleri harfi harfine kullanlmak iin \ ile doldurun.';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Este';
+$strEvent = 'Olay';
 $strExcelEdition = 'Excel yaps';
-$strExcelOptions = 'Excel seenekleri';
 $strExecuteBookmarked = 'aretlenmi sorguyu altr';
 $strExplain = 'SQL\'i akla';
 $strExport = 'Dar Aktar';
@@ -294,10 +291,10 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Baarsz deneme';
 $strField = 'Alan';
 $strFieldHasBeenDropped = '%s alan kaldrld';
-$strFields = 'Alanlar';
-$strFieldsEmpty = ' Alan says bo! ';
+$strFieldInsertFromFileTempDirNotExists = 'Gnderilen dosyay tama hatas, SSS 1.11\'e bakn';
 $strFieldsEnclosedBy = 'Alanlar kapsayan:';
 $strFieldsEscapedBy = 'Alanlar dolduran:';
+$strFields = 'Alanlar';
 $strFieldsTerminatedBy = 'Alanlar sonlandran:';
 $strFileAlreadyExists = '%s dosyas zaten sunucuda var, dosya adn deitirin veya zerine yazma seeneini iaretleyin.';
 $strFileCouldNotBeRead = 'Dosya okunamad';
@@ -307,13 +304,14 @@ $strFileNameTemplateDescriptionServer = 'sunucu ad';
 $strFileNameTemplateDescriptionTable = 'tablo ad';
 $strFileNameTemplate = 'Dosya ad ablonu';
 $strFileNameTemplateRemember = 'ablonu hatrla';
+$strFiles = 'Dosyalar';
 $strFileToImport = 'eri aktarmak iin dosya';
 $strFixed = 'Sabit';
 $strFlushPrivilegesNote = 'Not: phpMyAdmin kullanclarn yetkilerini dorudan MySQL\'in yetki tablolarndan alr. Bu tablolarn ierikleri, eer elle deitirildiyse sunucunun kulland yetkilerden farkl olabilir. Bu durumda devam etmeden nce %syetkileri yeniden yklemeniz%s gerekir.';
 $strFlushQueryCache = 'Sorgu nbelleini temizle';
 $strFlushTables = 'Tm tablolar temizle (kapat)';
 $strFlushTable = 'Tabloyu temizle ("FLUSH")';
-$strFontSize = 'Taz Tipi boyutu';
+$strFontSize = 'Yaz Tipi boyutu';
 $strForeignKeyError = 'D anahtar oluturma hatas (veri trlerini kontrol edin)';
 $strFormat = 'Biim';
 $strFormEmpty = 'Formda eksik deer!';
@@ -343,7 +341,7 @@ $strHasBeenCreated = 'oluturuldu.';
 $strHaveToShow = 'Grntlemek iin en az bir stun semelisiniz';
 $strHebrew = 'branice';
 $strHelp = 'Yardm';
-$strHexForBinary = 'Binari alanlar iin onaltlk say sistemini kullan';
+$strHexForBLOB = 'BLOB iin onaltlk sistem kullan';
 $strHide         = 'Gizle';
 $strHideShowAll = 'Tmn Gizle/Gster';
 $strHideShowNoRelation = 'likisi olmayan Tablolar Gizle/Gster';
@@ -352,9 +350,7 @@ $strHomepageOfficial = 'Resm phpMyAdmin Anasayfas';
 $strHost = 'Anamakine';
 $strHostEmpty = 'Anamakine ad bo!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 dar aktarma seenekleri';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 dar aktarma seenekleri';
 $strHungarian = 'Macarca';
 
 $strIcelandic = 'zlandaca';
@@ -370,13 +366,11 @@ $strImportFormat = 'eri aktarlm dosyann biimi';
 $strImportSuccessfullyFinished = 'eri aktarma baarl olarak bitti, %d sorgu altrld.';
 $strImport = 'eri Aktar';
 $strIndexes = 'ndeksler';
+$strIndexesSeemEqual = 'Aadaki indeksler eit olarak grnyor ve bunlardan biri kaldrlmaldr:';
 $strIndexHasBeenDropped = '%s indeksi kaldrld';
 $strIndexName = 'ndeks ismi:';
 $strIndexType = 'ndeks tr :';
-$strIndexWarningMultiple = 'Birden fazla %s anahtar `%s` stunu iin oluturuldu.';
-$strIndexWarningPrimary = 'PRIMARY ve INDEX anahtarlarnn her ikisi de `%s` stunu iin ayarlanmamaldr.';
 $strIndexWarningTable = '`%s` tablosunun indeksleri ile ilgili sorunlar';
-$strIndexWarningUnique = 'UNIQUE ve INDEX anahtarlarnn her ikisi de `%s` stunu iin ayarlanmamaldr.';
 $strIndex = 'ndeks';
 $strInnoDBAutoextendIncrement = 'Art miktarn otomatik genilet';
 $strInnoDBAutoextendIncrementDesc = 'Tablo dolduunda otomatik genileyen tablo alannn genilemesi iin art miktar boyutu.';
@@ -427,7 +421,6 @@ $strKorean = 'Korece';
 
 $strLandscape = 'Peyzaj';
 $strLanguage = 'Dil';
-$strLanguageFileNotFound = 'Dil dosyas "%1$s" bulunamad.';
 $strLanguageUnknown = 'Bilinmeyen dil: %1$s.';
 $strLatchedPages = 'Sabitlenmi sayfalar';
 $strLatexCaption = 'Tablo bal';
@@ -437,10 +430,8 @@ $strLatexContinued = '(devam eden)';
 $strLatexIncludeCaption = 'Tablo baln dahil et';
 $strLatexLabel = 'Etiket anahtar';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX seenekleri';
 $strLatexStructure = '__TABLE__ tablosunun yaps';
 $strLatvian = 'Litvanyaca';
-$strLDIImportOptions = 'VER YKLE kullanarak CSV ieri aktarm iin seenekler';
 $strLDILocal = 'YEREL anahtar kelime kullan';
 $strLDI = 'VER YKLE kullanarak CSV';
 $strLengthSet = 'Uzunluk/Deerler';
@@ -498,6 +489,7 @@ $strMyISAMSortBufferSizeDesc = 'Bir REPAIR TABLE komutu srasnda MyISAM indeksler
 $strMySQLCharset = 'MySQL karakter grubu';
 $strMysqlClientVersion = 'MySQL istemci srm';
 $strMySQLConnectionCollation = 'MySQL balant karlatrmas';
+$strMysqlLibDiffersServerVersion = 'PHP MySQL ktphanenizin %s srm MySQL sunucunuzun %s srmnden farkl. Bu tarafsz davrana sebep olabilir.';
 $strMySQLSaid = 'MySQL kts: ';
 $strMySQLShowProcess = 'lemleri gster';
 $strMySQLShowStatus = 'MySQL alma sresi bilgisini gster';
@@ -544,13 +536,12 @@ $strNumTables = 'Tablolar';
 
 $strOK = 'TAMAM';
 $strOpenDocumentSpreadsheet = 'Ak Belge Hesap izelgesi';
-$strOpenDocumentSpreadsheetOptions = 'Ak Belge Hesap izelgesi seenekleri';
 $strOpenDocumentText = 'Ak Belge Metini';
-$strOpenDocumentTextOptions = 'Ak Belge Metini seenekleri';
 $strOpenNewWindow = 'Yeni phpMyAdmin penceresi a';
 $strOperations = 'lemler';
 $strOperator = 'letici';
 $strOptimizeTable = 'Tabloyu uyarla';
+$strOptions = 'Seenekler';
 $strOr = 'Veya';
 $strOverhead = 'Ek Yk';
 $strOverwriteExisting = 'Mevcut dosya(larn)nn zerine yaz';
@@ -568,7 +559,6 @@ $strPassword = 'Parola';
 $strPdfDbSchema = ' "%s" veritabannn emas - Sayfa %s';
 $strPdfInvalidTblName = ' "%s" tablosu yok!';
 $strPdfNoTables = 'Tablolar yok';
-$strPDFOptions = 'PDF seenekleri';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Tek tablonun verisini ieren bir rapor retir)';
 $strPDFReportTitle = 'Rapor bal';
@@ -677,12 +667,15 @@ $strReplaceTable = 'Tablo verisini dosya ile deitir';
 $strReplication = 'oaltma';
 $strReset = 'Sfrla';
 $strResourceLimits = 'Kaynak snrlar';
+$strRestartInsertion = '%s satrl eklemeyi yeniden balat';
 $strReType = 'Yeniden gir';
 $strRevokeAndDeleteDescr = 'Kullanclar, yetkiler yeniden yklenene kadar hala USAGE yetkisine sahip olacaklar.';
 $strRevokeAndDelete = 'Kullanclardan tm aktif yetkileri geri al ve sonra da sil.';
 $strRevoke = 'Geri al';
 $strRevokeMessage = '%s iin yetkileri geri aldnz';
 $strRomanian = 'Romence';
+$strRoutines = 'Yordamlar';
+$strRoutineReturnType = 'Dn tr';
 $strRowLength = 'Satr uzunluu';
 $strRowsFrom = 'satr, balayaca kayt numaras:';
 $strRowSize = ' Satr boyutu ';
@@ -734,6 +727,7 @@ $strServerTabVariables = 'Deikenler';
 $strServerTrafficNotes = '<b>Sunucu trafii</b>: Bu tablolar sunucunun balatld andan itibaren MySQL sunucusunun a trafii istatistiklerini gsterir.';
 $strServerVars = 'Sunucu deikenleri ve ayarlar';
 $strServerVersion = 'Sunucu srm';
+$strSessionStartupErrorGeneral = 'Oturum hatasz olarak balatlamyor, ltfen PHP ve/veya web sunucusu gnl dosyanzda verilen hatalar kontrol edin ve PHP kurulumunuzu dzgn olarak yaplandrn.';
 $strSessionValue = 'Oturum deeri';
 $strSetEnumVal = 'Eer alan tr "enum" veya "set" ise ltfen deerleri bu biimi kullanarak girin: \'a\',\'b\',\'c\'...<br />Eer bu deerler arasna hep ters eik izgi ("\") veya tek trnak ("\'") koymanz gerekirse, nlerine ters eik izgi koyun (rnein \'\\\\xyz\' veya \'a\\\'b\').';
 $strShowAll = 'Tmn gster';
@@ -823,7 +817,7 @@ $strShowStatusKey_readsDescr = 'Diskten anahtar blounun fiziksel okunma saysdr.
 $strShowStatusKey_write_requestsDescr = 'nbellee anahtar blou yazmak iin istek saysdr.';
 $strShowStatusKey_writesDescr = 'Diske anahtar blounu fiziksel yazma saysdr.';
 $strShowStatusLast_query_costDescr = 'Sorgu en iyileyicisi tarafndan hesaplanm gibi son derlenen sorgunun toplam maliyetidir. Ayn sorgu iin farkl sorgu planlarnn maliyetini karlatrmak iin yararldr. Varsaylan deer 0, henz derlenmi sorgu olmad anlamna gelir.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAY sralarnda yazlmak iin bekleyen satr saysdr.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAYED sralarnda yazlmak iin bekleyen satr saysdr.';
 $strShowStatusOpened_tablesDescr = 'Ak olan tablo saysdr. Eer ak tablolar bykse, tablo nbellek deeriniz muhtemelen ok kktr.';
 $strShowStatusOpen_filesDescr = 'Ak olan dosya saysdr.';
 $strShowStatusOpen_streamsDescr = 'Ak olan ak saysdr (balca gnlkleme iin kullanlr).';
@@ -878,8 +872,6 @@ $strSpanish = 'spanyolca';
 $strSplitWordsWithSpace = 'Kelimeler bolukla ayrlr (" ").';
 $strSQLCompatibility = 'SQL uyumluluk kipi';
 $strSQLExportType = 'Dar aktarma tr';
-$strSQLImportOptions = 'SQL seenekleri';
-$strSQLOptions = 'SQL seenekleri';
 $strSQLParserBugMessage = 'SQL ayrtrcsnda bir hata bulabilme ihtimaliniz var. Ltfen sorgunuzu yakndan dikkatli bir ekilde gzden geirin ve trnaklarn doru ve uyumsuz olmadn kontrol edin. Dier muhtemel hata nedenleri trnakl metin alannn dnda binari ile dosya gnderiyor olmanz olabilir. Ayn zamanda sorgunuzu MySQL komut satr arabiriminde deneyebilirsiniz. Eer hata varsa, aadaki MySQL sunucu hata kts, sorunu tehis etmenizde ayrca size yardmc olabilir. Eer hala sorunlarnz varsa ya da komut satr arabirimi baarl olduunda ayrtrc baarszsa, ltfen sorunlara neden olan SQL sorgu giriinizi tek bir sorguya indirgeyin ve aadaki CUT blm iindeki veri yn ile birlikte hata raporunu gnderin:';
 $strSQLParserUserError = 'SQL sorgunuzda bir hata olduu grnyor. Eer varsa, aadaki MySQL sunucu hata kts, sorunu tehis etmenizde ayrca size yardmc olabilir.';
 $strSQLQuery = 'SQL sorgusu';
@@ -901,7 +893,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Yap ve Veri';
 $strStrucExcelCSV = 'MS Excel iin CSV';
 $strStrucNativeExcel = 'Bamsz MS Excel biimi';
-$strStrucNativeExcelOptions = 'Bamsz Excel dar aktarma seenekleri';
 $strStrucOnly = 'Sadece yap';
 $strStructPropose = 'Tablo yaps ner';
 $strStructureForView = 'Grnm yaps';
@@ -967,6 +958,7 @@ $strTransformation_text_plain__imagelink = 'Bir resim ve bir balant grntler; ala
 $strTransformation_text_plain__link = 'Bir balant grntler; alan dosya adn ierir. lk seenek "http://www.adresim.com/" gibi bir URL n ekidir. kinci seenek balant iin balktr.';
 $strTransformation_text_plain__sql = 'Szdizimi vurgulamal SQL sorgusu gibi metni biimlendirir.';
 $strTransformation_text_plain__substr = 'Karakter dizisinin bir ksmn grntler. lk seenek dizginin balangcndan atlamak iin karakter saysdr (Varsaylan 0). kinci seenek dndrlecek karakter saysdr (Varsaylan: dizginin sonuna kadar). nc seenek ksaltma meydana geldiinde eklemek ve/veya baa eklemek iin dizgidir (Varsaylan: "...").';
+$strTriggers = 'Tetiklemeler';
 $strTruncateQueries = 'Gsterilen Sorgular Ksalt';
 $strTurkish = 'Trke';
 $strType = 'Tr';
@@ -983,6 +975,13 @@ $strUpdateProfileMessage = 'Profil gncellendi.';
 $strUpdateQuery = 'Sorguyu Gncelle';
 $strUpdComTab = 'Stun_Yorumlar tablonuzun nasl gncelleneceini renmek iin ltfen belgelere bakn.';
 $strUpgrade = '%s %s veya sonrasna ykseltmelisiniz.';
+$strUploadErrorCantWrite = 'Dosyay diske yazma baarsz.';
+$strUploadErrorExtension = 'Dosya gnderme uzantsndan dolay durduruldu.';
+$strUploadErrorFormSize = 'Gnderilen dosya, HTML formu iinde belirlenmi MAX_FILE_SIZE ynergesini ayor.';
+$strUploadErrorIniSize = 'Gnderilen dosya, php.ini iindeki upload_max_filesize ynergesini ayor.';
+$strUploadErrorNoTempDir = 'Eksik geici klasr.';
+$strUploadErrorPartial = 'Gnderilen dosya sadece ksmen gnderildi.';
+$strUploadErrorUnknown = 'Dosya gndermede bilinmeyen hata oldu.';
 $strUploadLimit = 'Muhtemelen ok byk dosya gndermeyi denediniz. Ltfen bu snra zm yolu bulmak iin %sbelgelere%s bavurun.';
 $strUploadsNotAllowed = 'Bu sunucuda dosya gnderimlerine izin verilmez.';
 $strUsage = 'Kullanm';
@@ -1010,9 +1009,10 @@ $strVersionInformation = 'Srm bilgisi';
 $strViewDumpDatabases = 'Veritabanlarnn dkmn (emasn) gster';
 $strViewDumpDB = 'Veritabannn dkmn (emasn) gster';
 $strViewDump = 'Tablonun dkmn (emasn) gster';
-$strView = 'Grnm';
 $strViewHasBeenDropped = '%s grnm kaldrld';
 $strViewMaxExactCount = 'Bu grnm %s satrdan daha fazla. Ltfen %sbelgelere%s bavurun.';
+$strViewName = 'GRNM ad';
+$strView = 'Grnm';
 
 $strWebServerUploadDirectoryError = 'Gnderme ii iin ayarladnz dizine ulalamyor';
 $strWebServerUploadDirectory = 'web sunucusu gnderme dizini';
@@ -1024,7 +1024,6 @@ $strWithChecked = 'Seilileri:';
 $strWriteRequests = 'Yazma istekleri';
 $strWrongUser = 'Yanl kullanc ad/parola. Eriim engellendi.';
 
-$strXMLOptions = 'XML seenekleri';
 $strXML = 'XML';
 
 $strYes = 'Evet';
@@ -1032,5 +1031,6 @@ $strYes = 'Evet';
 $strZeroRemovesTheLimit = 'Not: Bu seeneklerin 0 (sfr)\'a ayarlanmas snr kaldrr.';
 $strZip = '"zip olarak"';
 
-$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
