@@ -1,13 +1,20 @@
 <?php
-/* $Id: db_table_exists.lib.php 9636 2006-10-27 13:04:15Z nijel $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Ensure the database and the table exist (else move to the "parent" script)
  * and display headers
+ *
+ * @version $Id: db_table_exists.lib.php 12102 2008-12-09 14:03:57Z nijel $
+ */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
+
+/**
+ *
  */
 if (empty($is_db)) {
-    if (isset($db) && strlen($db)) {
+    if (strlen($db)) {
         $is_db = @PMA_DBI_select_db($db);
     } else {
         $is_db = false;
@@ -20,7 +27,7 @@ if (empty($is_db)) {
             if (isset($message)) {
                 $url_params['message'] = $message;
             }
-            if (isset($sql_query)) {
+            if (! empty($sql_query)) {
                 $url_params['sql_query'] = $sql_query;
             }
             if (isset($show_as_php)) {
@@ -36,7 +43,7 @@ if (empty($is_db)) {
 
 if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
     // Not a valid table name -> back to the db_sql.php
-    if (isset($table) && strlen($table)) {
+    if (strlen($table)) {
         $_result = PMA_DBI_try_query(
             'SHOW TABLES LIKE \'' . PMA_sqlAddslashes($table, true) . '\';',
             null, PMA_DBI_QUERY_STORE);
@@ -48,7 +55,7 @@ if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
 
     if (! $is_table) {
         if (! defined('IS_TRANSFORMATION_WRAPPER')) {
-            if (isset($table) && strlen($table)) {
+            if (strlen($table)) {
                 // SHOW TABLES doesn't show temporary tables, so try select
                 // (as it can happen just in case temporary table, it should be
                 // fast):
@@ -57,7 +64,7 @@ if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
                  * @todo should this check really only happen if IS_TRANSFORMATION_WRAPPER?
                  */
                 $_result = PMA_DBI_try_query(
-                    'SELECT COUNT(*) FROM `' . PMA_sqlAddslashes($table, true) . '`;',
+                    'SELECT COUNT(*) FROM ' . PMA_backquote($table) . ';',
                     null, PMA_DBI_QUERY_STORE);
                 $is_table = ($_result && @PMA_DBI_num_rows($_result));
                 PMA_DBI_free_result($_result);
@@ -68,7 +75,7 @@ if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
                 if (isset($message)) {
                     $url_params['message'] = $message;
                 }
-                if (isset($sql_query)) {
+                if (! empty($sql_query)) {
                     $url_params['sql_query'] = $sql_query;
                 }
                 if (isset($display_query)) {
