@@ -2,8 +2,11 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: mysql_charsets.lib.php 10588 2007-09-02 19:23:59Z lem9 $
+ * @version $Id: mysql_charsets.lib.php 11335 2008-06-21 14:01:54Z lem9 $
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  *
