@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: create-release.sh 9544 2006-10-13 07:40:50Z nijel $
+# $Id: create-release.sh 11913 2008-11-21 08:58:00Z nijel $
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # 2005-09-13, lem9@users.sourceforge.net
@@ -133,12 +133,12 @@ if [ "$mode" = "snapshot" -a "$2" = "sf" ] ; then
 fi
 
 # Do SVNcheckout
-mkdir -p ./svn 
+mkdir -p ./svn
 cd svn
 
 echo "Exporting repository from subversion"
 
-svn export -q https://svn.sourceforge.net/svnroot/phpmyadmin/$branch/phpMyAdmin
+svn export -q https://phpmyadmin.svn.sourceforge.net/svnroot/phpmyadmin/$branch/phpMyAdmin
 
 if [ $? -ne 0 ] ; then
     echo "Subversion checkout failed, bailing out"
@@ -222,16 +222,10 @@ echo
 echo "MD5 sums:"
 echo "--------"
 
-md5sum *.{gz,zip,bz2,7z} | sed "s/\([^ ]*\)[ ]*\([^ ]*\)/\$md5sum['\2'] = '\1';/"
+md5sum *.{gz,zip,bz2,7z} | sed "s/\([^ ]*\)[ ]*\([^ ]*\)/md5sum['\2'] = '\1'/"
 
 echo
-echo "Sizes:"
-echo "------"
-
-ls -l --block-size=k *.{gz,zip,bz2,7z} | sed -r "s/[a-z-]+[[:space:]]+[0-9]+[[:space:]]+[^[:space:]]+[[:space:]]+[^[:space:]]+[[:space:]]+([0-9]*)K.*[[:space:]]([^[:space:]]+)\$/\$size['\2'] = \1;/"
-
-echo
-echo "Add these to /home/groups/p/ph/phpmyadmin/htdocs/home_page/files.inc.php on sf"
+echo "Add these to website/data/md5.py in SVN"
 
 cat <<END
 
@@ -243,16 +237,11 @@ Todo now:
     version 2.7.0 gets two tags: RELEASE_2_7_0 and STABLE
     version 2.7.1-rc1 gets RELEASE_2_7_1RC1 and TESTING
 
- 2. upload the files to SF:
-        ftp upload.sourceforge.net
-        cd incoming
-        binary
-        mput svn/*.gz *.zip *.bz2
+ 2. upload the files to SF (procedure explained on the sf.net Admin/File Releases page)
  3. add files to SF files page (cut and paste changelog since last release)
  4. add SF news item to phpMyAdmin project
  5. update web page:
-        - add MD5s and file sizes to /home/groups/p/ph/phpmyadmin/htdocs/home_page/includes/list_files.inc.php
-        - add release to /home/groups/p/ph/phpmyadmin/htdocs/home_page/includes/list_release.inc.php
+        - add MD5s to website/data/md5.py in SVN
  6. announce release on freshmeat (http://freshmeat.net/projects/phpmyadmin/)
  7. send a short mail (with list of major changes) to
         phpmyadmin-devel@lists.sourceforge.net
@@ -273,9 +262,7 @@ Todo now:
  9. add a group for bug tracking this new version, at
     https://sourceforge.net/tracker/admin/index.php?group_id=23067&atid=377408&add_group=1
 
-10. Visit http://phpmyadmin.net/home_page/version.php then copy the results to /home/groups/p/ph/phpmyadmin/htdocs/latest.txt. This is needed for users of the pre-2.8.0 scripts/upgrade.pl.
-
-11. the end :-)
+10. the end :-)
 
 END
 
